==> nattable_1.6.0%2Bdfsg.orig.tar.xz: org.eclipse.nebula.widgets.nattable-1.6.0/org.eclipse.nebula.widgets.nattable.core/src/org/eclipse/nebula/widgets/nattable/ui/matcher/CellLabelMouseEventMatcher.java <==
/*******************************************************************************
 * Copyright (c) 2012 Original authors and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Original authors and others - initial API and implementation
 ******************************************************************************/
package org.eclipse.nebula.widgets.nattable.ui.matcher;

import org.eclipse.nebula.widgets.nattable.NatTable;
import org.eclipse.nebula.widgets.nattable.layer.LabelStack;
import org.eclipse.nebula.widgets.nattable.ui.NatEventData;
import org.eclipse.swt.events.MouseEvent;

/**
 * Matches mouse clicks on cells to which a specified configuration label has
 * been applied.
 */
public class CellLabelMouseEventMatcher extends MouseEventMatcher {

    private final String labelToMatch;

    public CellLabelMouseEventMatcher(String regionName, int button,
            String labelToMatch) {
        super(regionName, button);
        this.labelToMatch = labelToMatch;
    }

    public CellLabelMouseEventMatcher(int stateMask, String regionName,
            int button, String labelToMatch) {
        super(stateMask, regionName, button);
        this.labelToMatch = labelToMatch;
    }

    @Override
    public boolean matches(NatTable natTable, MouseEvent event,
            LabelStack regionLabels) {
        NatEventData eventData = NatEventData.createInstanceFromEvent(event);
        LabelStack customLabels = natTable.getConfigLabelsByPosition(
                eventData.getColumnPosition(), eventData.getRowPosition());

        return super.matches(natTable, event, regionLabels)
                && customLabels.getLabels().contains(this.labelToMatch);
    }

}

==> nattable_2.0.0%2Bdfsg.orig.tar.xz: org.eclipse.nebula.widgets.nattable-2.0.0/org.eclipse.nebula.widgets.nattable.core/src/org/eclipse/nebula/widgets/nattable/ui/matcher/CellLabelMouseEventMatcher.java <==
/*******************************************************************************
 * Copyright (c) 2012, 2020 Original authors and others.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Original authors and others - initial API and implementation
 ******************************************************************************/
package org.eclipse.nebula.widgets.nattable.ui.matcher;

import org.eclipse.nebula.widgets.nattable.NatTable;
import org.eclipse.nebula.widgets.nattable.layer.LabelStack;
import org.eclipse.nebula.widgets.nattable.ui.NatEventData;
import org.eclipse.swt.events.MouseEvent;

/**
 * Matches mouse clicks on cells to which a specified configuration label has
 * been applied.
 */
public class CellLabelMouseEventMatcher extends MouseEventMatcher {

    private final String labelToMatch;

    public CellLabelMouseEventMatcher(String regionName, int button, String labelToMatch) {
        super(regionName, button);
        this.labelToMatch = labelToMatch;
    }

    public CellLabelMouseEventMatcher(int stateMask, String regionName, int button, String labelToMatch) {
        super(stateMask, regionName, button);
        this.labelToMatch = labelToMatch;
    }

    @Override
    public boolean matches(NatTable natTable, MouseEvent event, LabelStack regionLabels) {
        NatEventData eventData = NatEventData.createInstanceFromEvent(event);
        LabelStack customLabels = natTable.getConfigLabelsByPosition(
                eventData.getColumnPosition(), eventData.getRowPosition());

        return super.matches(natTable, event, regionLabels)
                && customLabels.contains(this.labelToMatch);
    }

}
